@@ -18,7 +18,7 @@ class Heroku(cl1.CLI):
 				"-h / --help":"Show the documentation.",
 			},
 			options={},
-			alias="heroku",
+			alias="./heroku.py",
 			executable=__file__,)
 
 		#
